@@ -109,12 +109,14 @@ def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projecti
         singer.write_message(record_message)
 
         rows_synced += 1
-        seq_number_bookmarks.append({shard['ShardId'] : record['dynamodb']['SequenceNumber']})
+        seq_number_bookmarks[shard['ShardId']]=record['dynamodb']['SequenceNumber']
+
         state = singer.write_bookmark(state, table_name, 'shard_seq_numbers', seq_number_bookmarks)
         # Every 100 rows write the state
         if rows_synced % 100 == 0:
             singer.write_state(state)
 
+    LOGGER.info("value updated in seq_number_bookmarks: %s",seq_number_bookmarks[shard['ShardId']])
     singer.write_state(state)
     return rows_synced
 
